@@ -16,7 +16,10 @@ class HTTPClient(base.HTTPClient):
     @staticmethod
     def response(response):
         return base.Response(
-            response.code, response.headers, response.body.decode('utf-8'))
+            response.code,
+            response.headers,
+            response.body.decode('utf-8'),
+            response.body)
 
     @gen.coroutine
     def _request(self, callback, request):
@@ -39,10 +42,12 @@ class HTTPClient(base.HTTPClient):
                                          validate_cert=self.verify)
         return self._request(callback, request)
 
-    def delete(self, callback, path, params=None):
+    def delete(self, callback, path, params=None, data=''):
         uri = self.uri(path, params)
         request = httpclient.HTTPRequest(uri, method='DELETE',
+                                         body='' if data is None else data,
                                          validate_cert=self.verify)
+        request.allow_nonstandard_methods = True
         return self._request(callback, request)
 
     def post(self, callback, path, params=None, data=''):
