@@ -2,7 +2,6 @@ from __future__ import absolute_import
 
 from six import b
 # noinspection PyUnresolvedReferences
-from six.moves import urllib
 from treq.client import HTTPClient as TreqHTTPClient
 from twisted.internet import reactor
 from twisted.internet.defer import inlineCallbacks, returnValue
@@ -32,40 +31,24 @@ class InsecureContextFactory(ClientContextFactory):
         return ClientContextFactory.getContext(self)
 
 
-class HTTPClient(object):
-    def __init__(self,
-                 host='127.0.0.1',
-                 port=8500,
-                 scheme='http',
-                 verify=True,
-                 contextFactory=None,
-                 **kwargs):
-        self.host = host
-        self.port = port
-        self.scheme = scheme
-        self.base_uri = '%s://%s:%s' % (self.scheme, self.host, self.port)
-
+class HTTPClient(base.HTTPClient):
+    def __init__(self, contextFactory, *args, **kwargs):
+        super(HTTPClient, self).__init__(*args, **kwargs)
         agent_kwargs = dict(
-            reactor=reactor, pool=HTTPConnectionPool(reactor), **kwargs)
+            reactor=reactor, pool=HTTPConnectionPool(reactor))
         if contextFactory is not None:
             # use the provided context factory
             agent_kwargs['contextFactory'] = contextFactory
-        elif not verify:
+        elif not self.verify:
             # if no context is provided and verify is set to false, use the
             # insecure context factory implementation
             agent_kwargs['contextFactory'] = InsecureContextFactory()
 
         self.client = TreqHTTPClient(Agent(**agent_kwargs))
 
-    def uri(self, path, params=None):
-        uri = self.base_uri + path
-        if not params:
-            return uri
-        return '%s?%s' % (uri, urllib.parse.urlencode(params))
-
     @staticmethod
-    def response(code, headers, text):
-        return base.Response(code, headers, text)
+    def response(code, headers, text, content):
+        return base.Response(code, headers, text, content)
 
     @staticmethod
     def compat_string(value):
@@ -87,7 +70,8 @@ class HTTPClient(object):
             for k, v in dict(response.headers.getAllRawHeaders()).items()
         ])
         body = yield response.text(encoding='utf-8')
-        returnValue((response.code, headers, body))
+        content = yield response.content()
+        returnValue((response.code, headers, body, content))
 
     @inlineCallbacks
     def request(self, callback, method, url, **kwargs):
@@ -134,20 +118,22 @@ class HTTPClient(object):
         returnValue(response)
 
     @inlineCallbacks
-    def delete(self, callback, path, params=None):
+    def delete(self, callback, path, params=None, data=''):
         uri = self.uri(path, params)
-        response = yield self.request(callback, 'delete', uri, params=params)
+        response = yield self.request(callback, 'delete',
+                                      uri, params=params, data=data)
         returnValue(response)
 
 
 class Consul(base.Consul):
     @staticmethod
-    def connect(host,
-                port,
-                scheme,
-                verify=True,
-                contextFactory=None,
-                **kwargs):
+    def http_connect(host,
+                     port,
+                     scheme,
+                     verify=True,
+                     cert=None,
+                     contextFactory=None,
+                     **kwargs):
         return HTTPClient(
-            host, port, scheme, verify=verify,
-            contextFactory=contextFactory, **kwargs)
+            contextFactory, host, port, scheme, verify=verify, cert=cert,
+            **kwargs)
